@@ -5,7 +5,6 @@
 #' is primarily limited to helping function examples.
 #' @param n `(integer(1))` \cr Number of samples
 #' @param trt,age,sex `(numeric(1))` \cr Coefficients for covariates.
-#' @param cutoff `(numeric(1))` \cr Deprecated, in future use `cens`.
 #' @param cens `(numeric(1))` \cr Proportion of censoring to be generated, cut-off time is then
 #' selected as the quantile that results in `cens`.
 #'
@@ -16,11 +15,7 @@
 #' simsurvdata()
 #'
 #' @export
-simsurvdata <- function(n = 100, trt = 2, age = 2, sex = 1.5, cutoff = NULL, cens = 0.3) {
-
-  if (!is.null(cutoff)) {
-    stop("`cutoff` is now deprecated, in the future please use `cens`.")
-  }
+simsurvdata <- function(n = 100, trt = 2, age = 2, sex = 1.5, cens = 0.3) {
 
   covs <- data.frame(
     sexF = stats::rbinom(n, 1, 0.5),
@@ -33,9 +28,7 @@ simsurvdata <- function(n = 100, trt = 2, age = 2, sex = 1.5, cutoff = NULL, cen
 
   time <- stats::rweibull(nrow(covs), shape = shape, scale = scale)
 
-  if (is.null(cutoff)) {
-    cutoff <- as.numeric(stats::quantile(time, 1 - cens))
-  }
+  cutoff <- as.numeric(stats::quantile(time, 1 - cens))
 
   status <- as.integer(time <= cutoff)
   time[time > cutoff] <- cutoff
